@@ -18,12 +18,27 @@
 
 #pragma once
 
+#include "rwlock.hpp"
+#include "tofrom_string.hpp"
+#include "nonstd/optional.hpp"
+
 #include <string>
 #include <vector>
 
-struct Branch
+#include <stdint.h>
+#include <pthread.h>
+
+class Branch : public ToFromString
 {
-  enum Mode
+public:
+  Branch(const uint64_t &default_minfreespace);
+
+public:
+  int from_string(const std::string &str);
+  std::string to_string(void) const;
+
+public:
+  enum class Mode
     {
       INVALID,
       RO,
@@ -31,26 +46,53 @@ struct Branch
       NC
     };
 
+public:
   Mode        mode;
   std::string path;
+  uint64_t    minfreespace() const;
 
+public:
+  void set_minfreespace(const uint64_t minfreespace);
+
+public:
   bool ro(void) const;
   bool nc(void) const;
   bool ro_or_nc(void) const;
+
+private:
+  nonstd::optional<uint64_t>  _minfreespace;
+  const uint64_t             *_default_minfreespace;
 };
 
-class Branches : public std::vector<Branch>
+typedef std::vector<Branch> BranchVec;
+
+class Branches : public ToFromString
 {
 public:
-  std::string to_string(const bool mode_ = false) const;
-
-  void to_paths(std::vector<std::string> &vec_) const;
+  Branches(const uint64_t &default_minfreespace_);
 
 public:
-  void set(const std::string &str_);
-  void add_begin(const std::string &str_);
-  void add_end(const std::string &str_);
-  void erase_begin(void);
-  void erase_end(void);
-  void erase_fnmatch(const std::string &str_);
+  int from_string(const std::string &str);
+  std::string to_string(void) const;
+
+public:
+  void to_paths(std::vector<std::string> &vec) const;
+
+public:
+  mutable pthread_rwlock_t lock;
+  BranchVec vec;
+  const uint64_t &default_minfreespace;
+};
+
+class SrcMounts : public ToFromString
+{
+public:
+  SrcMounts(Branches &b_);
+
+public:
+  int from_string(const std::string &str);
+  std::string to_string(void) const;
+
+private:
+  Branches &_branches;
 };
