@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __ERRNO_HPP__
-#define __ERRNO_HPP__
+#pragma once
 
 #include <errno.h>
 
@@ -30,5 +29,3 @@
 #if !defined(ENOATTR) && !defined(ENODATA)
 #error "Neither ENOATTR or ENODATA defined: please contact mergerfs author with platform information"
 #endif
-
-#endif
