@@ -18,33 +18,35 @@
 
 #include "errno.h"
 #include "fs_attr.hpp"
-#include "fs_base_chmod.hpp"
-#include "fs_base_chown.hpp"
-#include "fs_base_mkdir.hpp"
-#include "fs_base_stat.hpp"
-#include "fs_base_utime.hpp"
 #include "fs_clonepath.hpp"
+#include "fs_lchown.hpp"
+#include "fs_lstat.hpp"
+#include "fs_lutimens.hpp"
+#include "fs_mkdir.hpp"
 #include "fs_path.hpp"
 #include "fs_xattr.hpp"
 #include "ugid.hpp"
 
 using std::string;
 
-static
-bool
-ignorable_error(const int err)
+namespace l
 {
-  switch(err)
-    {
-    case ENOTTY:
-    case ENOTSUP:
+  static
+  bool
+  ignorable_error(const int err_)
+  {
+    switch(err_)
+      {
+      case ENOTTY:
+      case ENOTSUP:
 #if ENOTSUP != EOPNOTSUPP
-    case EOPNOTSUPP:
+      case EOPNOTSUPP:
 #endif
-      return true;
-    }
+        return true;
+      }
 
-  return false;
+    return false;
+  }
 }
 
 namespace fs
@@ -54,12 +56,12 @@ namespace fs
     The directories which already exist are left alone.
     The new directories have metadata set to match the original if
     possible. Optionally ignore errors on metadata copies.
-   */
+  */
   int
-  clonepath(const string &fromsrc,
-            const string &tosrc,
-            const char   *relative,
-            const bool    return_metadata_errors)
+  clonepath(const string &fromsrc_,
+            const string &tosrc_,
+            const char   *relative_,
+            const bool    return_metadata_errors_)
   {
     int         rv;
     struct stat st;
@@ -67,25 +69,25 @@ namespace fs
     string      frompath;
     string      dirname;
 
-    if((relative == NULL) || (relative[0] == '\0'))
+    if((relative_ == NULL) || (relative_[0] == '\0'))
       return 0;
 
-    dirname = fs::path::dirname(relative);
+    dirname = fs::path::dirname(relative_);
     if(!dirname.empty())
       {
-        rv = fs::clonepath(fromsrc,tosrc,dirname);
+        rv = fs::clonepath(fromsrc_,tosrc_,dirname,return_metadata_errors_);
         if(rv == -1)
           return -1;
       }
 
-    frompath = fs::path::make(fromsrc,relative);
-    rv = fs::stat(frompath,&st);
+    frompath = fs::path::make(fromsrc_,relative_);
+    rv = fs::lstat(frompath,&st);
     if(rv == -1)
       return -1;
     else if(!S_ISDIR(st.st_mode))
       return (errno=ENOTDIR,-1);
 
-    topath = fs::path::make(tosrc,relative);
+    topath = fs::path::make(tosrc_,relative_);
     rv = fs::mkdir(topath,st.st_mode);
     if(rv == -1)
       {
@@ -97,58 +99,61 @@ namespace fs
 
     // it may not support it... it's fine...
     rv = fs::attr::copy(frompath,topath);
-    if(return_metadata_errors && (rv == -1) && !ignorable_error(errno))
+    if(return_metadata_errors_ && (rv == -1) && !l::ignorable_error(errno))
       return -1;
 
     // it may not support it... it's fine...
     rv = fs::xattr::copy(frompath,topath);
-    if(return_metadata_errors && (rv == -1) && !ignorable_error(errno))
+    if(return_metadata_errors_ && (rv == -1) && !l::ignorable_error(errno))
       return -1;
 
     rv = fs::lchown_check_on_error(topath,st);
-    if(return_metadata_errors && (rv == -1))
+    if(return_metadata_errors_ && (rv == -1))
       return -1;
 
-    rv = fs::utime(topath,st);
-    if(return_metadata_errors && (rv == -1))
+    rv = fs::lutimens(topath,st);
+    if(return_metadata_errors_ && (rv == -1))
       return -1;
 
     return 0;
   }
 
   int
-  clonepath(const string &from,
-            const string &to,
-            const string &relative,
-            const bool    return_metadata_errors)
+  clonepath(const string &from_,
+            const string &to_,
+            const string &relative_,
+            const bool    return_metadata_errors_)
   {
-    return fs::clonepath(from,to,relative.c_str(),return_metadata_errors);
+    return fs::clonepath(from_,
+                         to_,
+                         relative_.c_str(),
+                         return_metadata_errors_);
   }
 
   int
-  clonepath_as_root(const string &from,
-                    const string &to,
-                    const char   *relative,
-                    const bool    return_metadata_errors)
+  clonepath_as_root(const string &from_,
+                    const string &to_,
+                    const char   *relative_,
+                    const bool    return_metadata_errors_)
   {
-    if((relative == NULL) || (relative[0] == '\0'))
+    if((relative_ == NULL) || (relative_[0] == '\0'))
       return 0;
-    if(from == to)
+    if(from_ == to_)
       return 0;
 
     {
       const ugid::SetRootGuard ugidGuard;
 
-      return fs::clonepath(from,to,relative,return_metadata_errors);
+      return fs::clonepath(from_,to_,relative_,return_metadata_errors_);
     }
   }
 
   int
-  clonepath_as_root(const string &from,
-                    const string &to,
-                    const string &relative,
-                    const bool    return_metadata_errors)
+  clonepath_as_root(const string &from_,
+                    const string &to_,
+                    const string &relative_,
+                    const bool    return_metadata_errors_)
   {
-    return fs::clonepath_as_root(from,to,relative.c_str(),return_metadata_errors);
+    return fs::clonepath_as_root(from_,to_,relative_.c_str(),return_metadata_errors_);
   }
 }
