@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_CLONEPATH_HPP__
-#define __FS_CLONEPATH_HPP__
+#pragma once
 
 #include <string>
 
@@ -23,10 +22,19 @@ namespace fs
 {
   int clonepath(const std::string &from,
                 const std::string &to,
-                const char        *relative);
+                const char        *relative,
+                const bool         return_metadata_errors = false);
   int clonepath(const std::string &from,
                 const std::string &to,
-                const std::string &relative);
-}
+                const std::string &relative,
+                const bool         return_metadata_errors = false);
 
-#endif
+  int clonepath_as_root(const std::string &from,
+                        const std::string &to,
+                        const char        *relative,
+                        const bool         return_metadata_errors = false);
+  int clonepath_as_root(const std::string &from,
+                        const std::string &to,
+                        const std::string &relative,
+                        const bool         return_metadata_errors = false);
+}
