@@ -24,17 +24,11 @@
 
 namespace fs
 {
-  ssize_t
-  copy_file_range(const int           fd_in_,
-                  int64_t            *off_in_,
-                  const int           fd_out_,
-                  int64_t            *off_out_,
-                  const size_t        len_,
-                  const unsigned int  flags_);
-
-  ssize_t
-  copy_file_range(const int           fd_in_,
-                  const int           fd_out_,
-                  const size_t        len_,
-                  const unsigned int  flags_ = 0);
+  int64_t
+  copy_file_range(const int           fd_in,
+                  int64_t            *off_in,
+                  const int           fd_out,
+                  int64_t            *off_out,
+                  const uint64_t      len,
+                  const unsigned int  flags);
 }
