@@ -14,40 +14,24 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_FADVISE_HPP__
-#define __FS_FADVISE_HPP__
+#pragma once
 
-#ifndef POSIX_FADV_NORMAL
-# define POSIX_FADV_NORMAL 0
-#endif
-
-#ifndef POSIX_FADV_RANDOM
-# define POSIX_FADV_RANDOM 1
-#endif
-
-#ifndef POSIX_FADV_SEQUENTIAL
-# define POSIX_FADV_SEQUENTIAL 2
-#endif
-
-#ifndef POSIX_FADV_WILLNEED
-# define POSIX_FADV_WILLNEED 3
-#endif
-
-#ifndef POSIX_FADV_DONTNEED
-# define POSIX_FADV_DONTNEED 4
-#endif
-
-#ifndef POSIX_FADV_NOREUSE
-# define POSIX_FADV_NOREUSE 5
-#endif
+#include <sys/types.h>
 
 namespace fs
 {
   int
-  fadvise(const int   fd,
-          const off_t offset,
-          const off_t len,
-          const int   advice);
-}
+  fadvise_dontneed(const int   fd,
+                   const off_t offset = 0,
+                   const off_t len    = 0);
 
-#endif // __FS_FADVISE_HPP__
+  int
+  fadvise_willneed(const int   fd,
+                   const off_t offset = 0,
+                   const off_t len    = 0);
+
+  int
+  fadvise_sequential(const int   fd,
+                     const off_t offset = 0,
+                     const off_t len    = 0);
+}
