@@ -14,12 +14,14 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#pragma once
+
 #include <string>
 #include <vector>
 
 namespace fs
 {
   void
-  glob(const std::string        &pattern_,
-       std::vector<std::string> &strs_);
+  glob(const std::string        &pattern,
+       std::vector<std::string> *strs);
 }
