@@ -18,30 +18,33 @@
 
 #pragma once
 
-#include "fasthash.h"
+#include <string>
 
 #include <stdint.h>
 #include <sys/stat.h>
 
+
 namespace fs
 {
   namespace inode
   {
     static const uint64_t MAGIC = 0x7472617065786974;
 
-    inline
-    void
-    recompute(struct stat *st_)
-    {
-      uint64_t buf[5];
+    int set_algo(const std::string &s);
+    std::string get_algo(void);
 
-      buf[0] = st_->st_ino;
-      buf[1] = st_->st_dev;
-      buf[2] = buf[0] ^ buf[1];
-      buf[3] = buf[0] & buf[1];
-      buf[4] = buf[0] | buf[1];
+    uint64_t calc(const char     *fusepath,
+                  const uint64_t  fusepath_len,
+                  const mode_t    mode,
+                  const dev_t     dev,
+                  const ino_t     ion);
+    void calc(const char     *fusepath,
+              const uint64_t  fusepath_len,
+              struct stat    *st);
+    void calc(const char  *fusepath,
+              struct stat *st);
+    void calc(const std::string &fusepath,
+              struct stat       *st);
 
-      st_->st_ino = fasthash64(&buf[0],sizeof(buf),MAGIC);
-    }
   }
 }
