@@ -23,7 +23,7 @@
 namespace FUSE
 {
   int
-  create(const char     *fusepath_,
-         mode_t          mode_,
-         fuse_file_info *ffi_);
+  create(const char     *fusepath,
+         mode_t          mode,
+         fuse_file_info *ffi);
 }
