@@ -16,8 +16,8 @@
 
 #include "errno.hpp"
 #include "fileinfo.hpp"
-#include "fs_base_close.hpp"
-#include "fs_base_dup.hpp"
+#include "fs_close.hpp"
+#include "fs_dup.hpp"
 
 #include <fuse.h>
 
@@ -42,8 +42,7 @@ namespace l
 namespace FUSE
 {
   int
-  flush(const char     *fusepath_,
-        fuse_file_info *ffi_)
+  flush(fuse_file_info *ffi_)
   {
     FileInfo *fi = reinterpret_cast<FileInfo*>(ffi_->fh);
 
