@@ -16,7 +16,8 @@
 
 #include "errno.hpp"
 #include "fileinfo.hpp"
-#include "fs_base_fsync.hpp"
+#include "fs_fdatasync.hpp"
+#include "fs_fsync.hpp"
 
 #include <fuse.h>
 
@@ -43,8 +44,7 @@ namespace l
 namespace FUSE
 {
   int
-  fsync(const char     *fusepath_,
-        int             isdatasync_,
+  fsync(int             isdatasync_,
         fuse_file_info *ffi_)
   {
     FileInfo *fi = reinterpret_cast<FileInfo*>(ffi_->fh);
