@@ -21,7 +21,6 @@
 namespace FUSE
 {
   int
-  fsync(const char     *fusepath_,
-        int             isdatasync_,
-        fuse_file_info *ffi_);
+  fsync(int             isdatasync,
+        fuse_file_info *ffi);
 }
