@@ -16,7 +16,7 @@
 
 #include "errno.hpp"
 #include "dirinfo.hpp"
-#include "fs_base_fsync.hpp"
+#include "fs_fsync.hpp"
 
 #include <fuse.h>
 
@@ -42,8 +42,7 @@ namespace l
 namespace FUSE
 {
   int
-  fsyncdir(const char     *fusepath_,
-           int             isdatasync_,
+  fsyncdir(int             isdatasync_,
            fuse_file_info *ffi_)
   {
     DirInfo *di = reinterpret_cast<DirInfo*>(ffi_->fh);
