@@ -21,7 +21,6 @@
 namespace FUSE
 {
   int
-  fsyncdir(const char     *fusepath_,
-           int             isdatasync_,
-           fuse_file_info *ffi_);
+  fsyncdir(int             isdatasync,
+           fuse_file_info *ffi);
 }
