@@ -17,24 +17,85 @@
 #include "config.hpp"
 #include "errno.hpp"
 #include "fileinfo.hpp"
-#include "fs_base_open.hpp"
+#include "fs_lchmod.hpp"
 #include "fs_cow.hpp"
+#include "fs_fchmod.hpp"
+#include "fs_open.hpp"
 #include "fs_path.hpp"
+#include "fs_stat.hpp"
 #include "policy_cache.hpp"
-#include "rwlock.hpp"
+#include "stat_util.hpp"
 #include "ugid.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
 
 #include <string>
 #include <vector>
 
 using std::string;
 using std::vector;
-typedef Config::CacheFiles CacheFiles;
 
 namespace l
 {
+  static
+  bool
+  rdonly(const int flags_)
+  {
+    return ((flags_ & O_ACCMODE) == O_RDONLY);
+  }
+
+  static
+  int
+  lchmod_and_open_if_not_writable_and_empty(const string &fullpath_,
+                                            const int     flags_)
+  {
+    int rv;
+    struct stat st;
+
+    rv = fs::lstat(fullpath_,&st);
+    if(rv == -1)
+      return (errno=EACCES,-1);
+
+    if(StatUtil::writable(st))
+      return (errno=EACCES,-1);
+
+    rv = fs::lchmod(fullpath_,(st.st_mode|S_IWUSR|S_IWGRP));
+    if(rv == -1)
+      return (errno=EACCES,-1);
+
+    rv = fs::open(fullpath_,flags_);
+    if(rv == -1)
+      return (errno=EACCES,-1);
+
+    fs::fchmod(rv,st.st_mode);
+
+    return rv;
+  }
+
+  static
+  int
+  nfsopenhack(const std::string &fullpath_,
+              const int          flags_,
+              const NFSOpenHack  nfsopenhack_)
+  {
+    switch(nfsopenhack_)
+      {
+      default:
+      case NFSOpenHack::ENUM::OFF:
+        return (errno=EACCES,-1);
+      case NFSOpenHack::ENUM::GIT:
+        if(l::rdonly(flags_))
+          return (errno=EACCES,-1);
+        if(fullpath_.find("/.git/") == string::npos)
+          return (errno=EACCES,-1);
+        return l::lchmod_and_open_if_not_writable_and_empty(fullpath_,flags_);
+      case NFSOpenHack::ENUM::ALL:
+        if(l::rdonly(flags_))
+          return (errno=EACCES,-1);
+        return l::lchmod_and_open_if_not_writable_and_empty(fullpath_,flags_);
+      }
+  }
+
   /*
     The kernel expects being able to issue read requests when running
     with writeback caching enabled so we must change O_WRONLY to
@@ -61,27 +122,27 @@ namespace l
   {
     switch(config_.cache_files)
       {
-      case CacheFiles::LIBFUSE:
+      case CacheFiles::ENUM::LIBFUSE:
         ffi_->direct_io  = config_.direct_io;
         ffi_->keep_cache = config_.kernel_cache;
         ffi_->auto_cache = config_.auto_cache;
         break;
-      case CacheFiles::OFF:
+      case CacheFiles::ENUM::OFF:
         ffi_->direct_io  = 1;
         ffi_->keep_cache = 0;
         ffi_->auto_cache = 0;
         break;
-      case CacheFiles::PARTIAL:
+      case CacheFiles::ENUM::PARTIAL:
         ffi_->direct_io  = 0;
         ffi_->keep_cache = 0;
         ffi_->auto_cache = 0;
         break;
-      case CacheFiles::FULL:
+      case CacheFiles::ENUM::FULL:
         ffi_->direct_io  = 0;
         ffi_->keep_cache = 1;
         ffi_->auto_cache = 0;
         break;
-      case CacheFiles::AUTO_FULL:
+      case CacheFiles::ENUM::AUTO_FULL:
         ffi_->direct_io  = 0;
         ffi_->keep_cache = 0;
         ffi_->auto_cache = 1;
@@ -91,11 +152,12 @@ namespace l
 
   static
   int
-  open_core(const string &basepath_,
-            const char   *fusepath_,
-            const int     flags_,
-            const bool    link_cow_,
-            uint64_t     *fh_)
+  open_core(const string      &basepath_,
+            const char        *fusepath_,
+            const int          flags_,
+            const bool         link_cow_,
+            const NFSOpenHack  nfsopenhack_,
+            uint64_t          *fh_)
   {
     int fd;
     string fullpath;
@@ -106,6 +168,8 @@ namespace l
       fs::cow::break_link(fullpath.c_str());
 
     fd = fs::open(fullpath,flags_);
+    if((fd == -1) && (errno == EACCES))
+      fd = l::nfsopenhack(fullpath,flags_,nfsopenhack_);
     if(fd == -1)
       return -errno;
 
@@ -119,20 +183,20 @@ namespace l
   open(Policy::Func::Search  searchFunc_,
        PolicyCache          &cache,
        const Branches       &branches_,
-       const uint64_t        minfreespace_,
        const char           *fusepath_,
        const int             flags_,
        const bool            link_cow_,
+       const NFSOpenHack     nfsopenhack_,
        uint64_t             *fh_)
   {
     int rv;
     string basepath;
 
-    rv = cache(searchFunc_,branches_,fusepath_,minfreespace_,&basepath);
+    rv = cache(searchFunc_,branches_,fusepath_,&basepath);
     if(rv == -1)
       return -errno;
 
-    return l::open_core(basepath,fusepath_,flags_,link_cow_,fh_);
+    return l::open_core(basepath,fusepath_,flags_,link_cow_,nfsopenhack_,fh_);
   }
 }
 
@@ -142,23 +206,22 @@ namespace FUSE
   open(const char     *fusepath_,
        fuse_file_info *ffi_)
   {
-    const fuse_context      *fc     = fuse_get_context();
-    const Config            &config = Config::get(fc);
-    const ugid::Set          ugid(fc->uid,fc->gid);
-    const rwlock::ReadGuard  readlock(&config.branches_lock);
+    const fuse_context *fc     = fuse_get_context();
+    const Config       &config = Config::ro();
+    const ugid::Set     ugid(fc->uid,fc->gid);
 
     l::config_to_ffi_flags(config,ffi_);
 
     if(config.writeback_cache)
       l::tweak_flags_writeback_cache(&ffi_->flags);
 
-    return l::open(config.open,
+    return l::open(config.func.open.policy,
                    config.open_cache,
                    config.branches,
-                   config.minfreespace,
                    fusepath_,
                    ffi_->flags,
                    config.link_cow,
+                   config.nfsopenhack,
                    &ffi_->fh);
   }
 }
