@@ -22,7 +22,12 @@
 
 namespace num
 {
-  int to_uint64_t(const std::string &str_, uint64_t &value_);
-  int to_double(const std::string &str_, double *value_);
-  int to_time_t(const std::string &str_, time_t &value_);
+  int to_uint64_t(const std::string &str, uint64_t *value);
+  int to_double(const std::string &str, double *value);
+  int to_time_t(const std::string &str, time_t *value);
+}
+
+namespace num
+{
+  std::string humanize(const uint64_t bytes);
 }
