@@ -18,11 +18,15 @@
 
 #include "config.hpp"
 
+#include <string>
+#include <vector>
+
 #include <fuse.h>
 
 namespace options
 {
   void
-  parse(fuse_args *args,
-        Config    *config);
+  parse(fuse_args                *args,
+        Config                   *config,
+        std::vector<std::string> *errs);
 }
