@@ -18,9 +18,7 @@
 
 #include "branch.hpp"
 #include "category.hpp"
-#include "fs.hpp"
 
-#include <map>
 #include <string>
 #include <vector>
 
@@ -39,13 +37,19 @@ public:
         eplfs,
         eplus,
         epmfs,
+        eppfrd,
         eprand,
         erofs,
         ff,
         lfs,
         lus,
         mfs,
+        msplfs,
+        msplus,
+        mspmfs,
+        msppfrd,
         newest,
+        pfrd,
         rand,
         END
       };
@@ -58,43 +62,45 @@ public:
   {
     typedef std::string string;
     typedef std::vector<string> strvec;
-    typedef std::vector<const string*> cstrptrvec;
     typedef const string cstring;
     typedef const uint64_t cuint64_t;
     typedef const strvec cstrvec;
-    typedef const Category::Enum::Type CType;
 
-    typedef int (*Ptr)(CType,const Branches &,const char *,cuint64_t,cstrptrvec &);
+    typedef int (*Ptr)(Category,const Branches&,const char*,strvec *);
 
-    template <CType T>
+    template <Category T>
     class Base
     {
     public:
-      Base(const Policy *p)
-        : func(p->_func)
+      Base(const Policy &p_)
+        : func(p_._func)
+      {}
+
+      Base(const Policy *p_)
+        : func(p_->_func)
       {}
 
       int
-      operator()(const Branches &b,const char *c,cuint64_t d,cstrptrvec &e)
+      operator()(const Branches &a,const char *b,strvec *c)
       {
-        return func(T,b,c,d,e);
+        return func(T,a,b,c);
       }
 
       int
-      operator()(const Branches &b,const string &c,cuint64_t d,cstrptrvec &e)
+      operator()(const Branches &a,const string &b,strvec *c)
       {
-        return func(T,b,c.c_str(),d,e);
+        return func(T,a,b.c_str(),c);
       }
 
       int
-      operator()(const Branches &b,const char *c,cuint64_t d,string *e)
+      operator()(const Branches &a,const char *b,string *c)
       {
         int rv;
-        cstrptrvec v;
+        strvec v;
 
-        rv = func(T,b,c,d,v);
+        rv = func(T,a,b,&v);
         if(!v.empty())
-          *e = *v[0];
+          *c = v[0];
 
         return rv;
       }
@@ -103,25 +109,31 @@ public:
       const Ptr func;
     };
 
-    typedef Base<Category::Enum::action> Action;
-    typedef Base<Category::Enum::create> Create;
-    typedef Base<Category::Enum::search> Search;
+    typedef Base<Category::ACTION> Action;
+    typedef Base<Category::CREATE> Create;
+    typedef Base<Category::SEARCH> Search;
 
-    static int invalid(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int all(CType,const Branches&,const char*,cuint64_t,cstrptrvec&);
-    static int epall(CType,const Branches&,const char*,cuint64_t,cstrptrvec&);
-    static int epff(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int eplfs(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int eplus(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int epmfs(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int eprand(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int erofs(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int ff(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int lfs(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int lus(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int mfs(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int newest(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
-    static int rand(CType,const Branches&,const char *,cuint64_t,cstrptrvec&);
+    static int invalid(Category,const Branches&,const char *,strvec*);
+    static int all(Category,const Branches&,const char*,strvec*);
+    static int epall(Category,const Branches&,const char*,strvec*);
+    static int epff(Category,const Branches&,const char *,strvec*);
+    static int eplfs(Category,const Branches&,const char *,strvec*);
+    static int eplus(Category,const Branches&,const char *,strvec*);
+    static int epmfs(Category,const Branches&,const char *,strvec*);
+    static int eppfrd(Category,const Branches&,const char *,strvec*);
+    static int eprand(Category,const Branches&,const char *,strvec*);
+    static int erofs(Category,const Branches&,const char *,strvec*);
+    static int ff(Category,const Branches&,const char *,strvec*);
+    static int lfs(Category,const Branches&,const char *,strvec*);
+    static int lus(Category,const Branches&,const char *,strvec*);
+    static int mfs(Category,const Branches&,const char *,strvec*);
+    static int msplfs(Category,const Branches&,const char *,strvec*);
+    static int msplus(Category,const Branches&,const char *,strvec*);
+    static int mspmfs(Category,const Branches&,const char *,strvec*);
+    static int msppfrd(Category,const Branches&,const char *,strvec*);
+    static int newest(Category,const Branches&,const char *,strvec*);
+    static int pfrd(Category,const Branches&,const char *,strvec*);
+    static int rand(Category,const Branches&,const char *,strvec*);
   };
 
 private:
@@ -161,6 +173,7 @@ public:
   operator const std::string&() const { return _str; }
   operator const Func::Ptr() const { return _func; }
   operator const Policy*() const { return this; }
+  const std::string& to_string() const { return _str; }
 
   bool operator==(const Enum::Type enum_) const
   { return _enum == enum_; }
@@ -180,6 +193,7 @@ public:
   static const Policy &find(const Enum::Type);
 
 public:
+
   static const std::vector<Policy> _policies_;
   static const Policy * const      policies;
 
@@ -190,12 +204,29 @@ public:
   static const Policy &eplfs;
   static const Policy &eplus;
   static const Policy &epmfs;
+  static const Policy &eppfrd;
   static const Policy &eprand;
   static const Policy &erofs;
   static const Policy &ff;
   static const Policy &lfs;
   static const Policy &lus;
   static const Policy &mfs;
+  static const Policy &msplfs;
+  static const Policy &msplus;
+  static const Policy &mspmfs;
+  static const Policy &msppfrd;
   static const Policy &newest;
+  static const Policy &pfrd;
   static const Policy &rand;
 };
+
+namespace std
+{
+  static
+  inline
+  string
+  to_string(const Policy &p_)
+  {
+    return p_.to_string();
+  }
+}
