@@ -15,13 +15,13 @@
 */
 
 #include "errno.hpp"
-#include "fs.hpp"
 #include "fs_exists.hpp"
 #include "fs_info.hpp"
 #include "fs_path.hpp"
 #include "fs_statvfs_cache.hpp"
 #include "policy.hpp"
 #include "policy_error.hpp"
+#include "rwlock.hpp"
 
 #include <string>
 #include <vector>
@@ -33,10 +33,9 @@ namespace epall
 {
   static
   int
-  create(const Branches        &branches_,
-         const char            *fusepath,
-         const uint64_t         minfreespace,
-         vector<const string*> &paths)
+  create(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     int rv;
     int error;
@@ -48,22 +47,22 @@ namespace epall
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath))
-          error_and_continue(error,ENOENT);
         if(branch->ro_or_nc())
           error_and_continue(error,EROFS);
-        rv = fs::info(&branch->path,&info);
+        if(!fs::exists(branch->path,fusepath_))
+          error_and_continue(error,ENOENT);
+        rv = fs::info(branch->path,&info);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(info.readonly)
           error_and_continue(error,EROFS);
-        if(info.spaceavail < minfreespace)
+        if(info.spaceavail < branch->minfreespace())
           error_and_continue(error,ENOSPC);
 
-        paths.push_back(&branch->path);
+        paths_->push_back(branch->path);
       }
 
-    if(paths.empty())
+    if(paths_->empty())
       return (errno=error,-1);
 
     return 0;
@@ -71,9 +70,20 @@ namespace epall
 
   static
   int
-  action(const Branches        &branches_,
-         const char            *fusepath,
-         vector<const string*> &paths)
+  create(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return epall::create(branches_.vec,fusepath_,paths_);
+  }
+
+  static
+  int
+  action(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     int rv;
     int error;
@@ -85,20 +95,20 @@ namespace epall
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath))
-          error_and_continue(error,ENOENT);
         if(branch->ro())
           error_and_continue(error,EROFS);
+        if(!fs::exists(branch->path,fusepath_))
+          error_and_continue(error,ENOENT);
         rv = fs::statvfs_cache_readonly(branch->path,&readonly);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(readonly)
           error_and_continue(error,EROFS);
 
-        paths.push_back(&branch->path);
+        paths_->push_back(branch->path);
       }
 
-    if(paths.empty())
+    if(paths_->empty())
       return (errno=error,-1);
 
     return 0;
@@ -106,9 +116,20 @@ namespace epall
 
   static
   int
-  search(const Branches        &branches_,
-         const char            *fusepath,
-         vector<const string*> &paths)
+  action(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return epall::action(branches_.vec,fusepath_,paths_);
+  }
+
+  static
+  int
+  search(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     const Branch *branch;
 
@@ -116,34 +137,44 @@ namespace epall
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath))
+        if(!fs::exists(branch->path,fusepath_))
           continue;
 
-        paths.push_back(&branch->path);
+        paths_->push_back(branch->path);
       }
 
-    if(paths.empty())
+    if(paths_->empty())
       return (errno=ENOENT,-1);
 
     return 0;
   }
+
+  static
+  int
+  search(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return epall::search(branches_.vec,fusepath_,paths_);
+  }
 }
 
 int
-Policy::Func::epall(const Category::Enum::Type  type,
-                    const Branches             &branches_,
-                    const char                 *fusepath,
-                    const uint64_t              minfreespace,
-                    vector<const string*>      &paths)
+Policy::Func::epall(const Category  type_,
+                    const Branches &branches_,
+                    const char     *fusepath_,
+                    vector<string> *paths_)
 {
-  switch(type)
+  switch(type_)
     {
-    case Category::Enum::create:
-      return epall::create(branches_,fusepath,minfreespace,paths);
-    case Category::Enum::action:
-      return epall::action(branches_,fusepath,paths);
-    case Category::Enum::search:
+    case Category::CREATE:
+      return epall::create(branches_,fusepath_,paths_);
+    case Category::ACTION:
+      return epall::action(branches_,fusepath_,paths_);
+    case Category::SEARCH:
     default:
-      return epall::search(branches_,fusepath,paths);
+      return epall::search(branches_,fusepath_,paths_);
     }
 }
