@@ -15,13 +15,13 @@
 */
 
 #include "errno.hpp"
-#include "fs.hpp"
 #include "fs_exists.hpp"
 #include "fs_info.hpp"
 #include "fs_path.hpp"
 #include "fs_statvfs_cache.hpp"
 #include "policy.hpp"
 #include "policy_error.hpp"
+#include "rwlock.hpp"
 
 #include <limits>
 #include <string>
@@ -34,76 +34,86 @@ namespace epmfs
 {
   static
   int
-  create(const Branches        &branches_,
-         const char            *fusepath,
-         const uint64_t         minfreespace,
-         vector<const string*> &paths)
+  create(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     int rv;
     int error;
     uint64_t epmfs;
     fs::info_t info;
     const Branch *branch;
-    const string *epmfsbasepath;
+    const string *basepath;
 
     error = ENOENT;
     epmfs = std::numeric_limits<uint64_t>::min();
-    epmfsbasepath = NULL;
+    basepath = NULL;
     for(size_t i = 0, ei = branches_.size(); i != ei; i++)
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath))
-          error_and_continue(error,ENOENT);
         if(branch->ro_or_nc())
           error_and_continue(error,EROFS);
-        rv = fs::info(&branch->path,&info);
+        if(!fs::exists(branch->path,fusepath_))
+          error_and_continue(error,ENOENT);
+        rv = fs::info(branch->path,&info);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(info.readonly)
           error_and_continue(error,EROFS);
-        if(info.spaceavail < minfreespace)
+        if(info.spaceavail < branch->minfreespace())
           error_and_continue(error,ENOSPC);
         if(info.spaceavail < epmfs)
           continue;
 
         epmfs = info.spaceavail;
-        epmfsbasepath = &branch->path;
+        basepath = &branch->path;
       }
 
-    if(epmfsbasepath == NULL)
+    if(basepath == NULL)
       return (errno=error,-1);
 
-    paths.push_back(epmfsbasepath);
+    paths_->push_back(*basepath);
 
     return 0;
   }
 
   static
   int
-  action(const Branches        &branches_,
-         const char            *fusepath,
-         vector<const string*> &paths)
+  create(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return epmfs::create(branches_.vec,fusepath_,paths_);
+  }
+
+  static
+  int
+  action(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     int rv;
     int error;
     uint64_t epmfs;
     fs::info_t info;
     const Branch *branch;
-    const string *epmfsbasepath;
+    const string *basepath;
 
     error = ENOENT;
     epmfs = std::numeric_limits<uint64_t>::min();
-    epmfsbasepath = NULL;
+    basepath = NULL;
     for(size_t i = 0, ei = branches_.size(); i != ei; i++)
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath))
-          error_and_continue(error,ENOENT);
         if(branch->ro())
           error_and_continue(error,EROFS);
-        rv = fs::info(&branch->path,&info);
+        if(!fs::exists(branch->path,fusepath_))
+          error_and_continue(error,ENOENT);
+        rv = fs::info(branch->path,&info);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(info.readonly)
@@ -112,36 +122,47 @@ namespace epmfs
           continue;
 
         epmfs = info.spaceavail;
-        epmfsbasepath = &branch->path;
+        basepath = &branch->path;
       }
 
-    if(epmfsbasepath == NULL)
+    if(basepath == NULL)
       return (errno=error,-1);
 
-    paths.push_back(epmfsbasepath);
+    paths_->push_back(*basepath);
 
     return 0;
   }
 
   static
   int
-  search(const Branches        &branches_,
-         const char            *fusepath,
-         vector<const string*> &paths)
+  action(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return epmfs::action(branches_.vec,fusepath_,paths_);
+  }
+
+  static
+  int
+  search(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     int rv;
     uint64_t epmfs;
     uint64_t spaceavail;
     const Branch *branch;
-    const string *epmfsbasepath;
+    const string *basepath;
 
     epmfs = 0;
-    epmfsbasepath = NULL;
+    basepath = NULL;
     for(size_t i = 0, ei = branches_.size(); i != ei; i++)
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath))
+        if(!fs::exists(branch->path,fusepath_))
           continue;
         rv = fs::statvfs_cache_spaceavail(branch->path,&spaceavail);
         if(rv == -1)
@@ -150,33 +171,43 @@ namespace epmfs
           continue;
 
         epmfs = spaceavail;
-        epmfsbasepath = &branch->path;
+        basepath = &branch->path;
       }
 
-    if(epmfsbasepath == NULL)
+    if(basepath == NULL)
       return (errno=ENOENT,-1);
 
-    paths.push_back(epmfsbasepath);
+    paths_->push_back(*basepath);
 
     return 0;
   }
+
+  static
+  int
+  search(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return epmfs::search(branches_.vec,fusepath_,paths_);
+  }
 }
 
 int
-Policy::Func::epmfs(const Category::Enum::Type  type,
-                    const Branches             &branches_,
-                    const char                 *fusepath,
-                    const uint64_t              minfreespace,
-                    vector<const string*>      &paths)
+Policy::Func::epmfs(const Category  type_,
+                    const Branches &branches_,
+                    const char     *fusepath_,
+                    vector<string> *paths_)
 {
-  switch(type)
+  switch(type_)
     {
-    case Category::Enum::create:
-      return epmfs::create(branches_,fusepath,minfreespace,paths);
-    case Category::Enum::action:
-      return epmfs::action(branches_,fusepath,paths);
-    case Category::Enum::search:
+    case Category::CREATE:
+      return epmfs::create(branches_,fusepath_,paths_);
+    case Category::ACTION:
+      return epmfs::action(branches_,fusepath_,paths_);
+    case Category::SEARCH:
     default:
-      return epmfs::search(branches_,fusepath,paths);
+      return epmfs::search(branches_,fusepath_,paths_);
     }
 }
