@@ -15,13 +15,13 @@
 */
 
 #include "errno.hpp"
-#include "fs.hpp"
 #include "fs_exists.hpp"
 #include "fs_info.hpp"
 #include "fs_path.hpp"
 #include "fs_statvfs_cache.hpp"
 #include "policy.hpp"
 #include "policy_error.hpp"
+#include "rwlock.hpp"
 
 #include <string>
 #include <vector>
@@ -36,10 +36,9 @@ namespace newest
 {
   static
   int
-  create(const Branches        &branches_,
-         const char            *fusepath,
-         const uint64_t         minfreespace,
-         vector<const string*> &paths)
+  create(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     int rv;
     int error;
@@ -47,46 +46,57 @@ namespace newest
     struct stat st;
     fs::info_t info;
     const Branch *branch;
-    const string *newestbasepath;
+    const string *basepath;
 
     error = ENOENT;
     newest = std::numeric_limits<time_t>::min();
-    newestbasepath = NULL;
+    basepath = NULL;
     for(size_t i = 0, ei = branches_.size(); i != ei; i++)
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath,&st))
-          error_and_continue(error,ENOENT);
         if(branch->ro_or_nc())
           error_and_continue(error,EROFS);
+        if(!fs::exists(branch->path,fusepath_,&st))
+          error_and_continue(error,ENOENT);
         if(st.st_mtime < newest)
           continue;
-        rv = fs::info(&branch->path,&info);
+        rv = fs::info(branch->path,&info);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(info.readonly)
           error_and_continue(error,EROFS);
-        if(info.spaceavail < minfreespace)
+        if(info.spaceavail < branch->minfreespace())
           error_and_continue(error,ENOSPC);
 
         newest = st.st_mtime;
-        newestbasepath = &branch->path;
+        basepath = &branch->path;
       }
 
-    if(newestbasepath == NULL)
+    if(basepath == NULL)
       return (errno=error,-1);
 
-    paths.push_back(newestbasepath);
+    paths_->push_back(*basepath);
 
     return 0;
   }
 
   static
   int
-  action(const Branches        &branches_,
-         const char            *fusepath,
-         vector<const string*> &paths)
+  create(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return newest::create(branches_.vec,fusepath_,paths_);
+  }
+
+  static
+  int
+  action(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     int rv;
     int error;
@@ -94,19 +104,19 @@ namespace newest
     time_t newest;
     struct stat st;
     const Branch *branch;
-    const string *newestbasepath;
+    const string *basepath;
 
     error = ENOENT;
     newest = std::numeric_limits<time_t>::min();
-    newestbasepath = NULL;
+    basepath = NULL;
     for(size_t i = 0, ei = branches_.size(); i != ei; i++)
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath,&st))
-          error_and_continue(error,ENOENT);
         if(branch->ro())
           error_and_continue(error,EROFS);
+        if(!fs::exists(branch->path,fusepath_,&st))
+          error_and_continue(error,ENOENT);
         if(st.st_mtime < newest)
           continue;
         rv = fs::statvfs_cache_readonly(branch->path,&readonly);
@@ -116,67 +126,88 @@ namespace newest
           error_and_continue(error,EROFS);
 
         newest = st.st_mtime;
-        newestbasepath = &branch->path;
+        basepath = &branch->path;
       }
 
-    if(newestbasepath == NULL)
+    if(basepath == NULL)
       return (errno=error,-1);
 
-    paths.push_back(newestbasepath);
+    paths_->push_back(*basepath);
 
     return 0;
   }
 
   static
   int
-  search(const Branches        &branches_,
-         const char            *fusepath,
-         vector<const string*> &paths)
+  action(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return newest::action(branches_.vec,fusepath_,paths_);
+  }
+
+  static
+  int
+  search(const BranchVec &branches_,
+         const char      *fusepath_,
+         vector<string>  *paths_)
   {
     time_t newest;
     struct stat st;
     const Branch *branch;
-    const string *newestbasepath;
+    const string *basepath;
 
     newest = std::numeric_limits<time_t>::min();
-    newestbasepath = NULL;
+    basepath = NULL;
     for(size_t i = 0, ei = branches_.size(); i != ei; i++)
       {
         branch = &branches_[i];
 
-        if(!fs::exists(branch->path,fusepath,&st))
+        if(!fs::exists(branch->path,fusepath_,&st))
           continue;
         if(st.st_mtime < newest)
           continue;
 
         newest = st.st_mtime;
-        newestbasepath = &branch->path;
+        basepath = &branch->path;
       }
 
-    if(newestbasepath == NULL)
+    if(basepath == NULL)
       return (errno=ENOENT,-1);
 
-    paths.push_back(newestbasepath);
+    paths_->push_back(*basepath);
 
     return 0;
   }
+
+  static
+  int
+  search(const Branches &branches_,
+         const char     *fusepath_,
+         vector<string> *paths_)
+  {
+    rwlock::ReadGuard guard(branches_.lock);
+
+    return newest::search(branches_.vec,fusepath_,paths_);
+  }
 }
 
 int
-Policy::Func::newest(const Category::Enum::Type  type,
-                     const Branches             &branches_,
-                     const char                 *fusepath,
-                     const uint64_t              minfreespace,
-                     vector<const string*>      &paths)
+Policy::Func::newest(const Category  type_,
+                     const Branches &branches_,
+                     const char     *fusepath_,
+                     vector<string> *paths_)
 {
-  switch(type)
+  switch(type_)
     {
-    case Category::Enum::create:
-      return newest::create(branches_,fusepath,minfreespace,paths);
-    case Category::Enum::action:
-      return newest::action(branches_,fusepath,paths);
-    case Category::Enum::search:
+    case Category::CREATE:
+      return newest::create(branches_,fusepath_,paths_);
+    case Category::ACTION:
+      return newest::action(branches_,fusepath_,paths_);
+    case Category::SEARCH:
     default:
-      return newest::search(branches_,fusepath,paths);
+      return newest::search(branches_,fusepath_,paths_);
     }
 }
