@@ -22,13 +22,24 @@
 namespace str
 {
   void
-  split(std::vector<std::string> &result,
-        const char               *str,
-        const char                delimiter);
+  split(const char               *str,
+        const char                delimiter,
+        std::vector<std::string> *result);
   void
-  split(std::vector<std::string> &result,
-        const std::string        &str,
-        const char                delimiter);
+  split(const std::string        &str,
+        const char                delimiter,
+        std::vector<std::string> *result);
+
+  void
+  rsplit1(const std::string        &str,
+          const char                delimiter,
+          std::vector<std::string> *result);
+
+  void
+  splitkv(const std::string &str,
+          const char         delimiter,
+          std::string       *key,
+          std::string       *value);
 
   std::string
   join(const std::vector<std::string> &vec,
@@ -58,6 +69,13 @@ namespace str
            const std::string &s1);
 
   bool
-  ends_with(const std::string &str_,
-            const std::string &suffix_);
+  startswith(const std::string &str_,
+             const std::string &prefix_);
+
+  bool
+  endswith(const std::string &str_,
+           const std::string &suffix_);
+
+  std::string
+  trim(const std::string &str);
 }
